Module: Core::Models::Concerns::Premiumable
- Extended by:
- ActiveSupport::Concern
- Included in:
- Permissions::Route
- Defined in:
- lib/core/models/concerns/premiumable.rb
Overview
Includes the premium field to make the entity including it accessible only to premium applications or not.