Module: Core::Models::Monitoring

Defined in:
lib/core/models/monitoring.rb,
lib/core/models/monitoring/route.rb,
lib/core/models/monitoring/service.rb

Overview

The monitoring module holds all the logic about the services so they can be activated or deactivated.

Author:

Defined Under Namespace

Classes: Route, Service