Module: Core::Models::Permissions
- Defined in:
- lib/core/models/permissions.rb,
lib/core/models/permissions/group.rb,
lib/core/models/permissions/right.rb,
lib/core/models/permissions/route.rb,
lib/core/models/permissions/category.rb
Overview
This module holds the logic for all the classes concerning the permissions abd rights for the user. A permission is restricting the access to one or several features to the users having it.