Class: Core::Models::Permissions::Group
- Inherits:
-
Object
- Object
- Core::Models::Permissions::Group
- Includes:
- Concerns::Sluggable, Mongoid::Document, Mongoid::Timestamps
- Defined in:
- lib/core/models/permissions/group.rb
Overview
A group gathers one or several users to give them the same rights for conviniency purposes.
Instance Attribute Summary collapse
-
#accounts ⇒ Array<Core::Models::Account>
The accounts having the rights granted by this group.
-
#is_default ⇒ Boolean
A boolean indicating whether this group is given when a new user registered or not.
-
#is_superuser ⇒ Boolean
A boolean indicating whether this group should have access to all groups and rights or not.
-
#rights ⇒ Array<Core::Models::Permissions::Right>
The rights granted by belonging to this group.
-
#routes ⇒ Array<Core::Models::Monitoring::Route>
The routes this group can access in the API.
Instance Attribute Details
#accounts ⇒ Array<Core::Models::Account>
Returns the accounts having the rights granted by this group.
22 |
# File 'lib/core/models/permissions/group.rb', line 22 has_and_belongs_to_many :accounts, class_name: 'Core::Models::Account', inverse_of: :groups |
#is_default ⇒ Boolean
Returns a boolean indicating whether this group is given when a new user registered or not.
15 |
# File 'lib/core/models/permissions/group.rb', line 15 field :is_default, type: Mongoid::Boolean, default: false |
#is_superuser ⇒ Boolean
Returns a boolean indicating whether this group should have access to all groups and rights or not.
18 |
# File 'lib/core/models/permissions/group.rb', line 18 field :is_superuser, type: Mongoid::Boolean, default: false |
#rights ⇒ Array<Core::Models::Permissions::Right>
Returns the rights granted by belonging to this group.
25 |
# File 'lib/core/models/permissions/group.rb', line 25 has_and_belongs_to_many :rights, class_name: 'Core::Models::Permissions::Right', inverse_of: :groups |
#routes ⇒ Array<Core::Models::Monitoring::Route>
Returns the routes this group can access in the API.
28 |
# File 'lib/core/models/permissions/group.rb', line 28 has_and_belongs_to_many :routes, class_name: 'Core::Models::Permissions::Route', inverse_of: :groups |