Class: Core::Models::Permissions::Route
- Inherits:
-
Object
- Object
- Core::Models::Permissions::Route
- Includes:
- Concerns::Activable, Concerns::Premiumable, Mongoid::Document, Mongoid::Timestamps
- Defined in:
- lib/core/models/permissions/route.rb
Overview
A route is an endpoint accessible in the API. Each route has to have an associated endpoint in the deployed instances.
Instance Attribute Summary collapse
-
#authenticated ⇒ Boolean
If true, the session_id is needed for this route, if false it is not.
-
#groups ⇒ Array<Core::Models::Permissions::Group>
The groups having permission to access this route.
-
#path ⇒ String
The path (URI) of the route in the API.
-
#verb ⇒ String
The verb (HTTP method) of this route in the API.
Instance Attribute Details
#authenticated ⇒ Boolean
Returns if true, the session_id is needed for this route, if false it is not.
22 |
# File 'lib/core/models/permissions/route.rb', line 22 field :authenticated, type: Mongoid::Boolean, default: true |
#groups ⇒ Array<Core::Models::Permissions::Group>
Returns the groups having permission to access this route.
25 |
# File 'lib/core/models/permissions/route.rb', line 25 has_and_belongs_to_many :groups, class_name: 'Core::Models::Permissions::Group', inverse_of: :groups |
#path ⇒ String
Returns the path (URI) of the route in the API.
16 |
# File 'lib/core/models/permissions/route.rb', line 16 field :path, type: String, default: '/' |
#verb ⇒ String
Returns the verb (HTTP method) of this route in the API.
19 |
# File 'lib/core/models/permissions/route.rb', line 19 field :verb, type: String, default: 'get' |